@@ -213,7 +213,9 @@ class RequestQueuer(object):
         return True
 
     def _checkActive(self):
-        while self.getActive() < self.max_simul_reqs and self.getPending() > 0:
+        
+        #self.pending_reqs = dict([(x[0],x[1]) for x in filter(lambda x:len(x[1]) > 0, self.pending_reqs.items())])
+        while self.getActive() < self.max_simul_reqs and self.getPending() > 0:        
             in_loop_req_count = 0
             for host in self.pending_reqs:
                 if self._hostRequestCheck(host):
@@ -224,22 +226,26 @@ class RequestQueuer(object):
                     d.addErrback(self._requestError, req["deferred"], host)
                     self.last_req[host] = time.time()
                     self.active_reqs[host] = self.active_reqs.get(host, 0) + 1
+            # Remove dictionary items of empty lists.
+            self.pending_reqs = dict([(x[0],x[1]) for x in filter(lambda x:len(x[1]) > 0, self.pending_reqs.items())])
             if in_loop_req_count == 0:
                 reactor.callLater(.1, self._checkActive)
                 return
+ 
 
     def _requestComplete(self, response, deferred, host):
         self.active_reqs[host] -= 1
-        if host in self.pending_reqs and len(self.pending_reqs[host]) == 0:
-            del self.pending_reqs[host]
+        #if host in self.pending_reqs and len(self.pending_reqs[host]) == 0:
+        #    del self.pending_reqs[host]
+        #
         self._checkActive()
         deferred.callback(response)
         return None
 
     def _requestError(self, error, deferred, host):
         self.active_reqs[host] -= 1
-        if host in self.pending_reqs and len(self.pending_reqs[host]) == 0:
-            del self.pending_reqs[host]
+        #if host in self.pending_reqs and len(self.pending_reqs[host]) == 0:
+        #    del self.pending_reqs[host]
         self._checkActive()
         deferred.errback(error)
         return None
